==> haskell-servant-server-0.16.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.16.2
id: servant-server-0.16.2-Ati19pL1HmUImA5lBt2Nkv
key: servant-server-0.16.2-Ati19pL1HmUImA5lBt2Nkv
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 9749acc4266b8829984ed564a122b778
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-server-0.16.2
hs-libraries: HSservant-server-0.16.2-Ati19pL1HmUImA5lBt2Nkv
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    base64-bytestring-1.0.0.2-7zYdD3kTvDlD1D30r2J6kg
    bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.2-HDaOvlvHbPR767FjhdL1tt filepath-1.4.2.1
    http-api-data-0.4.1-KBrkrzH16d3Hr7gAFEk2Uy
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-9Oghevaq5FtBD8UlWmZNzU
    monad-control-1.0.2.3-8DH4P9dnphD9L0cGYZ8UHr mtl-2.2.2
    network-2.8.0.0-1DkaUVvVIsp8sj7KmlE9xl
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-LNFC9oX9jZq9q4YtEcrXC
    servant-0.16.2-1wviQSMX1W070Ykqq1yXUT
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2
    transformers-base-0.4.5.2-II2bOKw9mMZBRrynUnHtTn
    wai-3.2.2.1-4WqDfhNhXZ1I8rnFCtCUIJ
    wai-app-static-3.1.6.3-FVauu1NON2yLuBjweJ02iO
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.16.2-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.16.2
id: servant-server-0.16.2-HnGOJsUTxDZBddKn022tui
key: servant-server-0.16.2-HnGOJsUTxDZBddKn022tui
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://docs.servant.dev/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: d69d93dea4d71bea0fdc5153de6a4ec4
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.Handler Servant.Server.Internal.RouteResult
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-server-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-server-0.16.2
hs-libraries: HSservant-server-0.16.2-HnGOJsUTxDZBddKn022tui
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-api-data-0.4.1-Gc0bKxYUFbHHGV70hcgEWB
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    servant-0.16.2-A9S9bnGMEnCGQ5FhsLyszH
    string-conversions-0.4.0.1-LtuUK6ZkUgfAmoIrlRp9AZ
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-app-static-3.1.6.3-D3UzEKCcOqL8pqt69ugm0A
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
